package
Version:
v0.0.0-...-d818996
Opens a new window with list of versions in this module.
Published: Jul 18, 2022
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ConsentFormData struct {
ConsentChallenge string `validate:"required" form:"consent_challenge"`
GrantScope []string `validate:"required" form:"grant_scope"`
}
type LoginFormData struct {
LoginChallenge string `validate:"required" form:"login_challenge"`
Email string `validate:"required" form:"email"`
Password string `validate:"required" form:"password"`
RememberMe string `validate:"required" form:"remember_me"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.